@@ -78,18 +78,37 @@ def getImageCluster( lon_deg,lat_deg, delta_long, delta_lat,zoom,printlog,imgsav
     apikey - openstreetmap token
     access_token - mapbox token
     '''
-    if style == 1:
-        smurl = r'https://tiles.wmflabs.org/bw-mapnik/{0}/{1}/{2}.png'
-    if style == 2:
-        smurl = r'http://a.tile.stamen.com/toner/{0}/{1}/{2}.png'
-    if style == 3:
-        smurl = r'http://c.tile.stamen.com/watercolor/{0}/{1}/{2}.png'
+    if (style == 1 )|(style == 'streets' ):
+        styleid = 'ckwinzgw581od14mpyfhka6nk'
+        smurl = r'https://api.mapbox.com/styles/v1/ni1o1/'+styleid+r'/tiles/256/{0}/{1}/{2}?&access_token='+access_token
+    if (style == 2 )|(style == 'outdoors' ):
+        styleid = 'ckwinx7aj4y4a15p7ftfwq9dn'
+        smurl = r'https://api.mapbox.com/styles/v1/ni1o1/'+styleid+r'/tiles/256/{0}/{1}/{2}?&access_token='+access_token
+    if (style == 3 )|(style == 'satellite' ):
+        styleid = 'cjv36cj9u4h1q1ftemjed4f2y'
+        smurl = r'https://api.mapbox.com/styles/v1/ni1o1/'+styleid+r'/tiles/256/{0}/{1}/{2}?&access_token='+access_token
     if (style == 4 )|(style == 'light' ):
         styleid = 'ckwfx658z4dpb14ocnz6tky9d'
         smurl = r'https://api.mapbox.com/styles/v1/ni1o1/'+styleid+r'/tiles/256/{0}/{1}/{2}?&access_token='+access_token
     if (style == 5 )|(style == 'dark' ):
         styleid = 'cjetnd20i1vbi2qqxbh0by7p8'
         smurl = r'https://api.mapbox.com/styles/v1/ni1o1/'+styleid+r'/tiles/256/{0}/{1}/{2}?&access_token='+access_token
+    if (style == 6 )|(style == 'light-ch' ):
+        styleid = 'ckj9bhq7s9mvj19mq3e3fye35'
+        smurl = r'https://api.mapbox.com/styles/v1/ni1o1/'+styleid+r'/tiles/256/{0}/{1}/{2}?&access_token='+access_token
+    if (style == 7 )|(style == 'ice creem' ):
+        styleid = 'cjv36iiz9243t1fo8mweb4z6r'
+        smurl = r'https://api.mapbox.com/styles/v1/ni1o1/'+styleid+r'/tiles/256/{0}/{1}/{2}?&access_token='+access_token
+    if (style == 8 )|(style == 'night' ):
+        styleid = 'ck2o3fyvy0dch1cp6j2pkz2dv'
+        smurl = r'https://api.mapbox.com/styles/v1/ni1o1/'+styleid+r'/tiles/256/{0}/{1}/{2}?&access_token='+access_token
+    if (style == 9 )|(style == 'terrain' ):
+        styleid = 'cjv36gyklf43q1fnuwibiuetl'
+        smurl = r'https://api.mapbox.com/styles/v1/ni1o1/'+styleid+r'/tiles/256/{0}/{1}/{2}?&access_token='+access_token
+    if (style == 10 )|(style == 'basic blue' ):
+        styleid = 'ckwio2ze12fgk15p2alr5a4xj'
+        smurl = r'https://api.mapbox.com/styles/v1/ni1o1/'+styleid+r'/tiles/256/{0}/{1}/{2}?&access_token='+access_token
+
     else:
         styleid = ''
     xmin, ymax =deg2num(lat_deg, lon_deg, zoom)
